@@ -3,6 +3,7 @@
 import boto3
 import json
 import os
+from botocore.exceptions import ClientError
 
 
 class S3Util:
@@ -21,6 +22,14 @@ class S3Util:
             raise ValueError('S3_BUCKET environment variable not set')
         return os.environ.get('S3_BUCKET')
 
+    def exists(self, key):
+        try:
+            client = boto3.client('s3')
+            client.head_object(Bucket=self.bucket_name(), Key=self.prefix(key))
+            return True
+        except ClientError:
+            return False
+
     def read_json(self, key):
         return json.loads(self.read_file(key))
 
